@@ -1,9 +1,10 @@
 #!/usr/bin/python -u
+import sys
 import libxml2
-import libxslt
-
 # Memory debug specific
 libxml2.debugMemory(1)
+import libxslt
+
 
 
 styledoc = libxml2.parseFile("test.xsl")
@@ -11,6 +12,10 @@ style = libxslt.parseStylesheetDoc(styledoc)
 doc = libxml2.parseFile("test.xml")
 result = style.applyStylesheet(doc, None)
 style.saveResultToFilename("foo", result, 0)
+stringval = style.saveResultToString(result)
+if (len(stringval) != 68):
+  print "Error in saveResultToString"
+  sys.exit(255)
 style.freeStylesheet()
 doc.freeDoc()
 result.freeDoc()
